summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xMaster/texmf/scripts/texlive/tlmgr.pl28
-rw-r--r--Master/tlpkg/TeXLive/TLPDB.pm24
2 files changed, 31 insertions, 21 deletions
diff --git a/Master/tlpkg/TeXLive/TLPDB.pm b/Master/tlpkg/TeXLive/TLPDB.pm
index 4f01c5899c4..010888ae0da 100644
--- a/Master/tlpkg/TeXLive/TLPDB.pm
+++ b/Master/tlpkg/TeXLive/TLPDB.pm
@@ -59,7 +59,7 @@ C<TeXLive::TLPDB> -- A database of TeX Live Packages
$tlpdb->config_doc_container;
$tlpdb->config_container_format;
$tlpdb->config_release;
- $tlpdb->config_maxrelease;
+ $tlpdb->config_minrelease;
$tlpdb->config_revision;
$tlpdb->options;
$tlpdb->option($key, [$value]);
@@ -930,17 +930,17 @@ sub config_release {
=pod
-=item C<< $tlpdb->config_maxrelease >>
+=item C<< $tlpdb->config_minrelease >>
-Returns the currently allowed maximal release. See Options below.
+Returns the currently allowed minimal release. See Options below.
=cut
-sub config_maxrelease {
+sub config_minrelease {
my $self = shift;
if (defined($self->{'tlps'}{'00texlive.config'})) {
foreach my $d ($self->{'tlps'}{'00texlive.config'}->depends) {
- if ($d =~ m!^maxrelease/(.*)$!) {
+ if ($d =~ m!^minrelease/(.*)$!) {
return "$1";
}
}
@@ -1370,9 +1370,9 @@ which set one or more of the following options:
=over 4
-=item C<container_split_src_files>
+=item C<container_split_src_files/[01]>
-=item C<container_split_doc_files>
+=item C<container_split_doc_files/[01]>
These options specify that at container generation time the source and
documentation files for a package have been put into a separate container
@@ -1383,6 +1383,16 @@ named C<package.source.extension> and C<package.doc.extension>.
This option specifies a format for containers. The currently supported
formats are C<xz> and C<zip>. But note that C<zip> is untested.
+=item C<release/I<relspec>>
+
+This option specifies the current release. The first four characters must
+be a year.
+
+=item C<minrelease/I<relspec>>
+
+This option specifies the minimum release for which this repository is
+valid.
+
=back
To set these options the respective lines should be added to
diff --git a/Master/texmf/scripts/texlive/tlmgr.pl b/Master/texmf/scripts/texlive/tlmgr.pl
index 799a8edabf6..7fed579640c 100755
--- a/Master/texmf/scripts/texlive/tlmgr.pl
+++ b/Master/texmf/scripts/texlive/tlmgr.pl
@@ -4555,18 +4555,18 @@ END_NO_INTERNET
$tlmediatlpdb = $tlmediasrc->tlpdb;
# we allow a range of years to be specified by the remote tlpdb
# for which it might work.
# the lower limit is TLPDB->config_release
# the upper limit is TLPDB->config_maxrelease
# if the later is not present only the year in config_release is accepted
# checks are done on the first 4 digits only
# Why only the first four places: some optional network distributions
# might use
# release/2009-foobar
# If it should work for 2009 and 2010, please use
- # release/2009-foobar
- # maxrelease/2010-foobar
+ # release/2010-foobar
+ # minrelease/2009-foobar
my $texlive_release = $tlmediatlpdb->config_release;
- my $texlive_maxrelease = $tlmediatlpdb->config_maxrelease;
+ my $texlive_minrelease = $tlmediatlpdb->config_minrelease;
if (!defined($texlive_release)) {
tldie "The installation repository does not specify a release year for which it was prepared, bailing out.\n";
}
@@ -4577,25 +4577,25 @@ END_NO_INTERNET
tldie "The installation repository does not specify a release year: $texlive_release, bailing out.\n";
}
# so $texlive_release_year is numeric, good
- if (defined($texlive_maxrelease)) {
+ if (defined($texlive_minrelease)) {
# we specify a range of years!
- my $texlive_maxrelease_year = $texlive_maxrelease;
- $texlive_maxrelease_year =~ s/^(....).*$/$1/;
- if ($texlive_maxrelease_year !~ m/^[1-9][0-9][0-9][0-9]$/) {
- tldie "The installation repository does not specify a valid maximal release year: $texlive_maxrelease, bailing out.\n";
+ my $texlive_minrelease_year = $texlive_minrelease;
+ $texlive_minrelease_year =~ s/^(....).*$/$1/;
+ if ($texlive_minrelease_year !~ m/^[1-9][0-9][0-9][0-9]$/) {
+ tldie "The installation repository does not specify a valid minimal release year: $texlive_minrelease, bailing out.\n";
}
# ok, all numeric and fine, check for range
- if ($TeXLive::TLConfig::ReleaseYear < $texlive_release_year
- || $TeXLive::TLConfig::ReleaseYear > $texlive_maxrelease_year) {
+ if ($TeXLive::TLConfig::ReleaseYear < $texlive_minrelease_year
+ || $TeXLive::TLConfig::ReleaseYear > $texlive_release_year) {
tldie <<END_BADRANGE
$0: The TeX Live versions supported by the repository
- ($texlive_release_year--$texlive_maxrelease_year)
+ ($texlive_minrelease_year--$texlive_release_year)
do not include the version of the local installation
($TeXLive::TLConfig::ReleaseYear). Goodbye.
END_BADRANGE
}
} else {
- # $texlive_maxrelease not defined, so only one year is valid
+ # $texlive_release not defined, so only one year is valid
if ($texlive_release_year != $TeXLive::TLConfig::ReleaseYear) {
tldie <<END_BADYEAR
$0: The TeX Live versions of the local installation
@@ -4555,18 +4555,18 @@ END_NO_INTERNET
# we allow a range of years to be specified by the remote tlpdb
# for which it might work.
- # the lower limit is TLPDB->config_release
- # the upper limit is TLPDB->config_maxrelease
+ # the lower limit is TLPDB->config_minrelease
+ # the upper limit is TLPDB->config_release
# if the later is not present only the year in config_release is accepted
# checks are done on the first 4 digits only